Module launch

Module launch 

The main entrypoint for this crate

Functions

launch
Launches the WebView and runs the event loop, with configuration and root props.
launch_virtual_dom
Launches the WebView and runs the event loop, with configuration and root props.
launch_virtual_dom_blocking
Launch the WebView and run the event loop, with configuration and root props.