pub struct LogicalPosition<P> {
pub x: P,
pub y: P,
}Expand description
A position represented in logical pixels.
The position is stored as floats, so please be careful. Casting floats to integers truncates the
fractional part, which can cause noticeable issues. To help with that, an Into<(i32, i32)>
implementation is provided which does the rounding for you.
Fields
x: Py: PImplementations
Sourceimpl<P> LogicalPosition<P>
impl<P> LogicalPosition<P>
pub const fn new(x: P, y: P) -> LogicalPosition<P>
Available on (Linux or macOS or Windows) and neither Android nor iOS only.
Sourceimpl<P> LogicalPosition<P>where
P: Pixel,
impl<P> LogicalPosition<P>where
P: Pixel,
pub fn from_physical<T, X>(physical: T, scale_factor: f64) -> LogicalPosition<P>
Available on (Linux or macOS or Windows) and neither Android nor iOS only.
pub fn to_physical<X>(&self, scale_factor: f64) -> PhysicalPosition<X>where
X: Pixel,
Available on (Linux or macOS or Windows) and neither Android nor iOS only.
pub fn cast<X>(&self) -> LogicalPosition<X>where
X: Pixel,
Available on (Linux or macOS or Windows) and neither Android nor iOS only.