pub struct RawKeyEvent {
    pub physical_key: KeyCode,
    pub state: ElementState,
}
Describes a keyboard input as a raw device event.

Note that holding down a key may produce repeated RawKeyEvents. The operating system doesn’t provide information whether such an event is a repeat or the initial keypress. An application may emulate this by, for example keeping a Map/Set of pressed keys and determining whether a keypress corresponds to an already pressed key.

Fields

physical_key: KeyCodestate: ElementState