Struct dioxus_desktop::tao::event_loop::EventLoopWindowTarget
pub struct EventLoopWindowTarget<T>where
T: 'static,{ /* private fields */ }Expand description
Target that associates windows with an EventLoop.
This type exists to allow you to create new windows while Tao executes
your callback. EventLoop will coerce into this type (impl<T> Deref for EventLoop<T>), so functions that take this as a parameter can also take
&EventLoop.
Implementations
impl<T> EventLoopWindowTarget<T>
impl<T> EventLoopWindowTarget<T>
pub fn available_monitors(&self) -> impl Iterator<Item = MonitorHandle>
pub fn available_monitors(&self) -> impl Iterator<Item = MonitorHandle>
Returns the list of all the monitors available on the system.
pub fn primary_monitor(&self) -> Option<MonitorHandle>
pub fn primary_monitor(&self) -> Option<MonitorHandle>
Returns the primary monitor of the system.
Returns None if it can’t identify any monitor as a primary one.
pub fn monitor_from_point(&self, x: f64, y: f64) -> Option<MonitorHandle>
pub fn monitor_from_point(&self, x: f64, y: f64) -> Option<MonitorHandle>
pub fn set_device_event_filter(&self, _filter: DeviceEventFilter)
pub fn set_device_event_filter(&self, _filter: DeviceEventFilter)
Change DeviceEvent filter mode.
Since the DeviceEvent capture can lead to high CPU usage for unfocused windows, tao
will ignore them by default for unfocused windows. This method allows changing
this filter at runtime to explicitly capture them again.
Platform-specific
- Linux / macOS / iOS / Android: Unsupported.