pub struct ContextMenu(_);
Object that allows you to create a ContextMenu.

Platform-specific

Implementations

Creates a new Menu for context (popup, tray etc..).

Add a submenu.

title could optionally contain an & before a character to assign this character as the mnemonic for this menu item. To display a & without assigning a mnemenonic, use &&

Platform-specific:
  • macOS: mnemonics are not supported but single & will be rmeoved anyways for consistency with other platforms.

Add new item to this menu.

Add new item to this menu.