pub struct MenuItemAttributes<'a> { /* private fields */ }
A custom menu item.

Implementations

Creates a new custom menu item.

title could optionally contain an & before a character to assign this character as the mnemonic for this menu item. To display a & without assigning a mnemenonic, use &&

Platform-specific:
  • macOS: mnemonics are not supported but single & will be rmeoved anyways for consistency with other platforms.

Assign a custom menu id.

Assign keyboard shortcut to the menu action.

Platform-specific
  • Windows / Android / iOS: Unsupported

Assign default menu state.

Assign default checkbox style.

Default is false

If selected is false, renders a regular menu item.