Struct dioxus_desktop::tao::monitor::MonitorHandle
pub struct MonitorHandle { /* private fields */ }Expand description
Handle to a monitor.
Allows you to retrieve information about a given monitor and can be used in Window creation.
Implementations
impl MonitorHandle
impl MonitorHandle
pub fn name(&self) -> Option<String>
pub fn name(&self) -> Option<String>
Returns a human-readable name of the monitor.
Returns None if the monitor doesn’t exist anymore.
pub fn size(&self) -> PhysicalSize<u32>
pub fn size(&self) -> PhysicalSize<u32>
Returns the monitor’s resolution.
pub fn position(&self) -> PhysicalPosition<i32>
pub fn position(&self) -> PhysicalPosition<i32>
Returns the top-left corner position of the monitor relative to the larger full screen area.
pub fn scale_factor(&self) -> f64
pub fn scale_factor(&self) -> f64
Returns the scale factor that can be used to map logical pixels to physical pixels, and vice versa.
See the dpi module for more information.
Platform-specific
- Android: Always returns 1.0.
pub fn video_modes(&self) -> impl Iterator<Item = VideoMode>
pub fn video_modes(&self) -> impl Iterator<Item = VideoMode>
Returns all fullscreen video modes supported by this monitor.
Platform-specific
- Linux: Unsupported. This will always return empty iterator.