Struct dioxus_desktop::tao::window::WindowId
pub struct WindowId(_);Expand description
Identifier of a window. Unique for each window.
Can be obtained with window.id().
Whenever you receive an event specific to a window, this event contains a WindowId which you
can then compare to the ids of your windows.
Implementations
impl WindowId
impl WindowId
pub unsafe fn dummy() -> WindowId
pub unsafe fn dummy() -> WindowId
Safety
Returns a dummy WindowId, useful for unit testing. The only guarantee made about the return
value of this function is that it will always be equal to itself and to future values returned
by this function. No other guarantees are made. This may be equal to a real WindowId.
Passing this into a tao function will result in undefined behavior.