Icon

Struct Icon 

pub struct Icon { /* private fields */ }
Available on (Windows or Linux or macOS) and neither iOS nor Android only.
An icon used for the window titlebar, taskbar, etc.

Implementations

Source

impl Icon

pub fn from_rgba( rgba: Vec<u8>, width: u32, height: u32, ) -> Result<Icon, BadIcon>

Creates an icon from 32bpp RGBA data.

The length of rgba must be divisible by 4, and width * height must equal rgba.len() / 4. Otherwise, this will return a BadIcon error.