Crate dioxus_desktop

Dioxus Desktop Renderer

Render the Dioxus VirtualDom using the platform’s native WebView implementation.

Desktop

One of Dioxus’ flagship features is the ability to quickly build a native desktop app that looks and feels the same across platforms. Apps built with Dioxus are typically <5mb in size and use existing system resources, so they won’t hog extreme amounts of RAM or memory.

Dioxus Desktop is built off Tauri. Right now there aren’t any Dioxus abstractions over the menubar, handling, etc, so you’ll want to leverage Tauri - mostly Wry and Tao directly. An upcoming release of Dioxus-Desktop will include components and hooks for notifications, global shortcuts, menubar, etc.

Getting Set up

Getting Set up with Dioxus-Desktop is quite easy. Make sure you have Rust and Cargo installed, and then create a new project:

$ cargo new --bin demo
$ cd app

Add Dioxus and the desktop renderer feature:

$ cargo add dioxus
$ cargo add dioxus-desktop

Edit your main.rs:

// main.rs
use dioxus::prelude::*;

fn main() {
    dioxus_desktop::launch(app);
}

fn app() -> Element {
    rsx! {
        div {
            "hello world!"
        }
    }
}

To configure the webview, menubar, and other important desktop-specific features, checkout out some of the launch configuration in the API reference.

Future Steps

Make sure to read the Dioxus Guide if you already haven’t!

Re-exports

Modules

Structs

Enums

Functions

  • Provide a callback to handle asset loading yourself.
  • Get a closure that executes any JavaScript in the WebView context.
  • use_muda_event_handlerWindows or Linux or macOS
    Register an event handler that runs when a muda event is processed.
  • use_tray_icon_event_handlerWindows or Linux or macOS
    Register an event handler that runs when a tray icon event is processed. This is only for tray icon and not it’s menus. If you want to register tray icon menus handler use use_tray_menu_event_handler instead.
  • use_tray_menu_event_handlerWindows or Linux or macOS
    Register an event handler that runs when a tray icon menu event is processed.
  • Get an imperative handle to the current window
  • Register an event handler that runs when a wry event is processed.
  • Get an imperative handle to the current window without using a hook

Type Aliases