Struct dioxus_desktop::Config

source ·
pub struct Config { /* private fields */ }
The configuration for the desktop application.

Implementations

Initializes a new WindowBuilder with default values.

set the directory from which assets will be searched in release mode

Set whether or not the right-click context menu should be disabled.

Set the pre-rendered HTML content

Set the configuration for the window.

Set a file drop handler

Set a custom protocol

Set a custom icon for this application

Inject additional content into the document’s HEAD.

This is useful for loading CSS libraries, JS libraries, etc.

Use a custom index.html instead of the default Dioxus one.

Make sure your index.html is valid HTML.

Dioxus injects some loader code into the closing body tag. Your document must include a body element!

Set the name of the element that Dioxus will use as the root.

This is akint to calling React.render() on the element with the specified name.