pub struct WindowBuilder {
    pub window: WindowAttributes,
    /* private fields */
}
Object that allows you to build windows.

Fields

window: WindowAttributes

The attributes to use to create the window.

Implementations

Initializes a new WindowBuilder with default values.

Requests the window to be of specific dimensions.

See Window::set_inner_size for details.

Sets a minimum dimension size for the window.

See Window::set_min_inner_size for details.

Sets a maximum dimension size for the window.

See Window::set_max_inner_size for details.

Sets a desired initial position for the window.

See WindowAttributes::position for details.

Sets whether the window is resizable or not.

See Window::set_resizable for details.

Sets whether the window is minimizable or not.

See Window::set_minimizable for details.

Sets whether the window is maximizable or not.

See Window::set_maximizable for details.

Sets whether the window is closable or not.

See Window::set_closable for details.

Requests a specific title for the window.

See Window::set_title for details.

Requests a specific menu for the window.

See Window::set_menu for details.

Sets the window fullscreen state.

See Window::set_fullscreen for details.

Requests maximized mode.

See Window::set_maximized for details.

Sets whether the window will be initially hidden or visible.

See Window::set_visible for details.

Sets whether the background of the window should be transparent.

Sets whether the window should have a border, a title bar, etc.

See Window::set_decorations for details.

Sets whether or not the window will always be below other windows.

See Window::set_always_on_bottom for details.

Sets whether or not the window will always be on top of other windows.

See Window::set_always_on_top for details.

Sets the window icon.

See Window::set_window_icon for details.

Forces a theme or uses the system settings if None was provided.

Whether the window will be initially focused or not.

Platform-specific:

Android / iOS: Unsupported.

Prevents the window contents from being captured by other apps.

Platform-specific
  • iOS / Android / Linux: Unsupported.

Builds the window.

Possible causes of error include denied permission, incompatible system, and lack of memory.