Struct dioxus_desktop::tao::event::RawKeyEvent
pub struct RawKeyEvent {
pub physical_key: KeyCode,
pub state: ElementState,
}Expand description
Describes a keyboard input as a raw device event.
Note that holding down a key may produce repeated RawKeyEvents. The
operating system doesn’t provide information whether such an event is a
repeat or the initial keypress. An application may emulate this by, for
example keeping a Map/Set of pressed keys and determining whether a keypress
corresponds to an already pressed key.
Fields
physical_key: KeyCodestate: ElementStateTrait Implementations
impl Clone for RawKeyEvent
impl Clone for RawKeyEvent
fn clone(&self) -> RawKeyEvent
fn clone(&self) -> RawKeyEvent
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for RawKeyEvent
impl Debug for RawKeyEvent
impl<'de> Deserialize<'de> for RawKeyEvent
impl<'de> Deserialize<'de> for RawKeyEvent
fn deserialize<__D>(
__deserializer: __D
) -> Result<RawKeyEvent, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D
) -> Result<RawKeyEvent, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Hash for RawKeyEvent
impl Hash for RawKeyEvent
impl PartialEq<RawKeyEvent> for RawKeyEvent
impl PartialEq<RawKeyEvent> for RawKeyEvent
fn eq(&self, other: &RawKeyEvent) -> bool
fn eq(&self, other: &RawKeyEvent) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl Serialize for RawKeyEvent
impl Serialize for RawKeyEvent
fn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more